@@ -16,7 +16,7 @@ class EventResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[list[EventDTO]], UnitError]:
+    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[List[EventDTO]], UnitError]:
         response = super().get(self.resource, {"page[limit]": limit, "page[offset]": offset})
         if super().is_20x(response.status_code):
             data = response.json().get("data")
